@@ -1,5 +1,5 @@
 ; libctl: flexible Guile-based control files for scientific software 
-; Copyright (C) 1998-2012 Massachusetts Institute of Technology and Steven G. Johnson
+; Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
 ;
 ; This library is free software; you can redistribute it and/or
 ; modify it under the terms of the GNU Lesser General Public
@@ -62,9 +62,9 @@
 	     append '()
 	     (map
 	      (lambda (x y)
-		(let ((m (inexact->exact 
+		(let ((m (inexact->exact (round
 			  (+ -0.5 (* (+ n 1) (/ (unary-abs (binary- x y))
-						meandiff))))))
+						meandiff)))))))
 		  (reverse (arith-sequence y (binary/ (binary- x y) (+ m 1)) 
 					   (+ m 1)))))
 	      (reverse (cdr (reverse nums))) ; nums w/o last value
