@@ -995,9 +995,9 @@ SCM cadaptive_integration_scm(SCM f_scm, SCM xmin_scm, SCM xmax_scm,
      cnumber integral;
 
      n = list_length(xmin_scm);
-     abstol = fabs(gh_scm2double(abstol_scm));
-     reltol = fabs(gh_scm2double(reltol_scm));
-     maxnfe = gh_scm2int(maxnfe_scm);
+     abstol = fabs(ctl_convert_number_to_c(abstol_scm));
+     reltol = fabs(ctl_convert_number_to_c(reltol_scm));
+     maxnfe = ctl_convert_integer_to_c(maxnfe_scm);
 
      if (list_length(xmax_scm) != n) {
 	  fprintf(stderr, "adaptive_integration: xmin/xmax dimension mismatch\n");
@@ -1035,7 +1035,7 @@ SCM cadaptive_integration_scm(SCM f_scm, SCM xmin_scm, SCM xmax_scm,
 	      break;
      }
      
-     return gh_cons(cnumber2scm(integral), gh_double2scm(abstol));
+     return gh_cons(cnumber2scm(integral), ctl_convert_number_to_scm(abstol));
 }
 
 #endif
